(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(['module', 'exports', 'babel-runtime/helpers/extends'], factory);
  } else if (typeof exports !== "undefined") {
    factory(module, exports, require('babel-runtime/helpers/extends'));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod, mod.exports, global._extends);
    global.AssertionFormatter = mod.exports;
  }
})(this, function (module, exports, _extends2) {
  'use strict';

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = AssertionFormatter;

  var _extends3 = _interopRequireDefault(_extends2);

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
      default: obj
    };
  }

  /**
   * ex. ['window', 'ServiceWorker'] => 'window.ServiceWorker'
   */
  /**
   * Take a record from a provider and create an assertion out of it. These
   * assertions are used to check if a browser supports a certain api
   *
   * 
   */

  /* eslint fp/no-throw: 0 */

  function formatJSAssertion(record) {
    var formattedProtoChain = record.protoChain.join('.');
    return 'return typeof ' + formattedProtoChain + ' !== undefined';
  }

  function formatCSSAssertion(record) {
    var cssPropertyName = record.protoChain[record.protoChain.length - 1];
    return 'return typeof Array.prototype.slice.call(document.defaultView.getComputedStyle(document.body, \'\'),0).indexOf(\'' + cssPropertyName + '\') > -1';
  }

  // function formatCSSPropertyAssertion(record: ProviderAPIResponse): string {
  //   return `CSS.supports ? CSS.supports('${record.}') : false`
  // }

  function AssertionFormatter(record) {
    switch (record.type) {
      case 'css-api':
        return (0, _extends3.default)({}, record, {
          assertion: formatCSSAssertion(record)
        });
      case 'js-api':
        return (0, _extends3.default)({}, record, {
          assertion: formatJSAssertion(record)
        });
      default:
        throw new Error('Invalid API type: "' + record.type + '"');
    }
  }
  module.exports = exports['default'];
});