(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(['exports', 'babel-runtime/core-js/number/is-nan', 'babel-runtime/helpers/extends', 'babel-runtime/core-js/array/from', './apicatalogdata.json'], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require('babel-runtime/core-js/number/is-nan'), require('babel-runtime/helpers/extends'), require('babel-runtime/core-js/array/from'), require('./apicatalogdata.json'));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global.isNan, global._extends, global.from, global.apicatalogdata);
    global.APICatalogProvider = mod.exports;
  }
})(this, function (exports, _isNan, _extends2, _from, _apicatalogdata) {
  'use strict';

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.camelToHyphen = camelToHyphen;
  exports.default = APICatalogProvider;

  var _isNan2 = _interopRequireDefault(_isNan);

  var _extends3 = _interopRequireDefault(_extends2);

  var _from2 = _interopRequireDefault(_from);

  var _apicatalogdata2 = _interopRequireDefault(_apicatalogdata);

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
      default: obj
    };
  }

  /**
   * Comvert camelcase phrases to hypen-separated words
   * ex. camelCase => camel-case
   * This is used to map CSS DOM API names to css properties and attributes
   */
  function camelToHyphen(string) {
    return (0, _from2.default)(string)
    // If char `X` is uppercase, map it to `-x`
    .map(function (curr) {
      return curr === curr.toUpperCase() ? '-' + curr.toLowerCase() : curr;
    }, []).join('');
  }

  /**
   * @TODO: Allow overriding database records
   */

  function APICatalogProvider() {
    var formattedRecords = [];

    // Convert two dimentional records to single dimentional array
    _apicatalogdata2.default.forEach(function (record) {
      return record.apis.forEach(function (api) {
        return formattedRecords.push((0, _extends3.default)({}, api, {
          spec: record.spec || false,
          parentName: record.name
        }));
      });
    });

    var JSAPIs = formattedRecords
    // Filter all CSS records. For some reason reason, APICatalog does not report
    // the correctly. Validate that the record's name is a string. Some record
    // names are numbers from some odd reason
    .filter(function (fRecord) {
      return !fRecord.name.includes('-') && fRecord.parentName !== 'CSS2Properties' && (0, _isNan2.default)(parseInt(fRecord.name, 10)) && typeof fRecord.spec !== 'undefined';
    }).map(function (fRecord) {
      return {
        id: fRecord.name,
        name: fRecord.name,
        specNames: fRecord.specNames,
        type: 'js-api',
        specIsFinished: fRecord.spec,
        protoChain: ['window', fRecord.parentName, fRecord.name]
      };
    });

    // Find the CSS DOM API's and use them create the css style records
    var CSSAPIs = JSAPIs.filter(function (record) {
      return record.protoChain.includes('CSSStyleDeclaration');
    }).map(function (record) {
      return (0, _extends3.default)({}, record, {
        id: camelToHyphen(record.name),
        name: camelToHyphen(record.name),
        type: 'css-api'
      });
    });

    return CSSAPIs.concat(JSAPIs);
    // return [...CSSAPIs, ...JSAPIs];
  }
});